@@ -39,7 +39,7 @@
  * Defining UINT8 as unsigned char is, ultimately, what stdint.h
  * would do anyway.
  */
-#if defined(_SGIAPI)
+#if defined(_SGIAPI) || defined( __sgi )
 	#define _CRYPT_RIJNDAEL_H_TYPES
 	typedef __uint32_t    UINT32;
 	typedef unsigned char UINT8;
@@ -48,8 +48,9 @@
 /* Solaris has sys/types.h, but doesn't act like everyone else 
  * GCC defines __sun__ and __sun (report from Todd Ross)
  * Solaris cc defines __sun
+ * MirBSD defines the same types as Solaris
  */
-#if defined( __sun__ ) || defined( __sun )
+#if defined( __sun__ ) || defined( __sun ) || defined( __MirBSD__ )
 	#define _CRYPT_RIJNDAEL_H_TYPES
 	typedef uint32_t UINT32;
 	typedef uint8_t  UINT8;
